<?php
/**
 * Social widget.
 *
 * @package    VT Blogging Pro
 * @author     VolThemes
 * @copyright  Copyright (c) 2018, VolThemes
 * @license    https://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
 
class vt_blogging_pro_social_widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'vt-social-widget widget_social_icons',
			'description' => __( 'Display your social media icons.', 'vt-blogging-pro' )
		);

		// Create the widget.
		parent::__construct(
			'vt-social-widget',                   		   // $this->id_base
			__( '[VT] Social Icons', 'vt-blogging-pro' ),  // $this->name
			$widget_options                         	   // $this->widget_options
		);
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	function widget( $args, $instance ) {
		extract( $args );

		// Output the theme's $before_widget wrapper.
		echo wp_kses_post($before_widget);

		// If the title not empty, display it.
		if ( $instance['title'] ) {
			echo wp_kses_post($before_title) . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . wp_kses_post($after_title);
		}
		if ( $instance['desc'] ) {
			echo '<div class="desc">' . esc_html( $instance['desc'] ) . '</div>';
		}

			// Display the social icons.
			echo '<div class="social-icons"><ul>';
				if ( $instance['facebook'] ) {
					echo '<li class="facebook"><a href="' . esc_url( $instance['facebook'] ) . '"  title="' . esc_html( 'Facebook', 'vt-blogging-pro' ) . '" class="fa fa-facebook" target="_blank"></a></li>';
				}
				if ( $instance['twitter'] ) {
					echo '<li class="twitter"><a href="' . esc_url( $instance['twitter'] ) . '" title="' . esc_html( 'Twitter', 'vt-blogging-pro' ) . '" class="fa fa-twitter" target="_blank"></a></li>';
				}	
				if ( $instance['pinterest'] ) {
					echo '<li class="pinterest"><a href="' . esc_url( $instance['pinterest'] ) . '" title="' . esc_html( 'Pinterest', 'vt-blogging-pro' ) . '" class="fa fa-pinterest-p" target="_blank"></a></li>';
				}
				if ( $instance['youtube'] ) {
					echo '<li class="youtube"><a href="' . esc_url( $instance['youtube'] ) . '" title="' . esc_html( 'Youtube', 'vt-blogging-pro' ) . '" class="fa fa-youtube-play" target="_blank"></a></li>';
				}
				if ( $instance['linkedin'] ) {
					echo '<li class="linkedin"><a href="' . esc_url( $instance['linkedin'] ) . '" title="' . esc_html( 'Linkedin', 'vt-blogging-pro' ) . '" class="fa fa-linkedin" target="_blank"></a></li>';
				}											
				if ( $instance['instagram'] ) {
					echo '<li class="instagram"><a href="' . esc_url( $instance['instagram'] ) . '" title="' . esc_html( 'Instagram', 'vt-blogging-pro' ) . '" class="fa fa-instagram" target="_blank"></a></li>';
				}
				if ( $instance['dribbble'] ) {
					echo '<li class="dribbble"><a href="' . esc_url( $instance['dribbble'] ) . '" title="' . esc_html( 'Dribbble', 'vt-blogging-pro' ) . '" class="fa fa-dribbble" target="_blank"></a></li>';
				}
				if ( $instance['tumblr'] ) {
					echo '<li class="tumblr"><a href="' . esc_url( $instance['tumblr'] ) . '" title="' . esc_html( 'Tumblr', 'vt-blogging-pro' ) . '" class="fa fa-tumblr" target="_blank"></a></li>';
				}
				if ( $instance['soundcloud'] ) {
					echo '<li class="soundcloud"><a href="' . esc_url( $instance['soundcloud'] ) . '" title="' . esc_html( 'Soundcloud', 'vt-blogging-pro' ) . '" class="fa fa-soundcloud" target="_blank"></a></li>';
				}
				if ( $instance['vk'] ) {
					echo '<li class="vk"><a href="' . esc_url( $instance['vk'] ) . '" title="' . esc_html( 'VK', 'vt-blogging-pro' ) . '" class="fa fa-vk" target="_blank"></a></li>';
				}
				if ( $instance['spotify'] ) {
					echo '<li class="spotify"><a href="' . esc_url( $instance['spotify'] ) . '" title="' . esc_html( 'Spotify', 'vt-blogging-pro' ) . '" class="fa fa-spotify" target="_blank"></a></li>';
				}
				if ( $instance['rss'] ) {
					echo '<li class="rss"><a href="' . esc_url( $instance['rss'] ) . '" title="' . esc_html( 'Feed', 'vt-blogging-pro' ) . '" class="fa fa-feed" target="_blank"></a></li>';
				}
			echo '</ul></div>';

		// Close the theme's widget wrapper.
		echo wp_kses_post($after_widget);

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	function update( $new_instance, $old_instance ) {

		$instance = $new_instance;

		$instance['title']      = strip_tags( $new_instance['title'] );
		$instance['desc']       = strip_tags( $new_instance['desc'] );		
		$instance['facebook']   = esc_url( $new_instance['facebook'] );
		$instance['twitter']    = esc_url( $new_instance['twitter'] );
		$instance['pinterest']  = esc_url( $new_instance['pinterest'] );
		$instance['youtube']    = esc_url( $new_instance['youtube'] );		
		$instance['linkedin']   = esc_url( $new_instance['linkedin'] );
		$instance['instagram']  = esc_url( $new_instance['instagram'] );
		$instance['dribbble']   = esc_url( $new_instance['dribbble'] );
		$instance['tumblr']     = esc_url( $new_instance['tumblr'] );
		$instance['soundcloud'] = esc_url( $new_instance['soundcloud'] );
		$instance['vk'] 		= esc_url( $new_instance['vk'] );
		$instance['spotify']	= esc_url( $new_instance['spotify'] );
		$instance['rss']        = esc_url( $new_instance['rss'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	function form( $instance ) {

		// Default value.
		$defaults = array(
			'title'      => esc_html__( 'Follow Us', 'vt-blogging-pro' ),
			'desc'       => esc_html__( 'Stay updated via social channels', 'vt-blogging-pro' ),		
			'facebook'   => '',
			'twitter'    => '',
			'pinterest'  => '',
			'youtube'    => '',			
			'linkedin'   => '',
			'instagram'  => '',
			'dribbble'   => '',
			'tumblr'     => '',
			'soundcloud' => '',
			'vk'		 => '',
			'spotify'	 => '',
			'rss'        => ''
		);

		$instance = wp_parse_args( (array) $instance, $defaults );
	?>

		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title', 'vt-blogging-pro' ); ?></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'desc' )); ?>"><?php esc_html_e( 'Description', 'vt-blogging-pro' ); ?></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'desc' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'desc' )); ?>" value="<?php echo esc_attr( $instance['desc'] ); ?>" />
		</p>		

		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'facebook' )); ?>"><?php esc_html_e( 'Facebook', 'vt-blogging-pro' ); ?></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'facebook' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'facebook' )); ?>" value="<?php echo esc_url( $instance['facebook'] ); ?>" placeholder="<?php echo esc_attr( 'https://', 'vt-blogging-pro' ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'twitter' )); ?>"><?php esc_html_e( 'Twitter', 'vt-blogging-pro' ); ?></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'twitter' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'twitter' )); ?>" value="<?php echo esc_url( $instance['twitter'] ); ?>" placeholder="<?php echo esc_attr( 'https://', 'vt-blogging-pro' ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'pinterest' )); ?>"><?php esc_html_e( 'Pinterest', 'vt-blogging-pro' ); ?></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'pinterest' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'pinterest' )); ?>" value="<?php echo esc_url( $instance['pinterest'] ); ?>" placeholder="<?php echo esc_attr( 'https://', 'vt-blogging-pro' ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'youtube' )); ?>"><?php esc_html_e( 'YouTube', 'vt-blogging-pro' ); ?></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'youtube' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'youtube' )); ?>" value="<?php echo esc_url( $instance['youtube'] ); ?>" placeholder="<?php echo esc_attr( 'https://', 'vt-blogging-pro' ); ?>" />
		</p>		

		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'linkedin' )); ?>"><?php esc_html_e( 'LinkedIn', 'vt-blogging-pro' ); ?></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'linkedin' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'linkedin' )); ?>" value="<?php echo esc_url( $instance['linkedin'] ); ?>" placeholder="<?php echo esc_attr( 'https://', 'vt-blogging-pro' ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'instagram' )); ?>"><?php esc_html_e( 'Instagram', 'vt-blogging-pro' ); ?></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'instagram' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'instagram' )); ?>" value="<?php echo esc_url( $instance['instagram'] ); ?>" placeholder="<?php echo esc_attr( 'https://', 'vt-blogging-pro' ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'dribbble' )); ?>"><?php esc_html_e( 'Dribbble', 'vt-blogging-pro' ); ?></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'dribbble' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'dribbble' )); ?>" value="<?php echo esc_url( $instance['dribbble'] ); ?>" placeholder="<?php echo esc_attr( 'https://', 'vt-blogging-pro' ); ?>" />
		</p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'tumblr' )); ?>"><?php esc_html_e( 'Tumblr', 'vt-blogging-pro' ); ?></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'tumblr' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'tumblr' )); ?>" value="<?php echo esc_url( $instance['tumblr'] ); ?>" placeholder="<?php echo esc_attr( 'https://', 'vt-blogging-pro' ); ?>" />
		</p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'soundcloud' )); ?>"><?php esc_html_e( 'Soundcloud', 'vt-blogging-pro' ); ?></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'soundcloud' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'soundcloud' )); ?>" value="<?php echo esc_url( $instance['soundcloud'] ); ?>" placeholder="<?php echo esc_attr( 'https://', 'vt-blogging-pro' ); ?>" />
		</p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'vk' )); ?>"><?php esc_html_e( 'VK', 'vt-blogging-pro' ); ?></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'vk' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'vk' )); ?>" value="<?php echo esc_url( $instance['vk'] ); ?>" placeholder="<?php echo esc_attr( 'https://', 'vt-blogging-pro' ); ?>" />
		</p>
		
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'spotify' )); ?>"><?php esc_html_e( 'Spotify', 'vt-blogging-pro' ); ?></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'spotify' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'spotify' )); ?>" value="<?php echo esc_url( $instance['spotify'] ); ?>" placeholder="<?php echo esc_attr( 'https://', 'vt-blogging-pro' ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'rss' )); ?>"><?php esc_html_e( 'RSS Feed', 'vt-blogging-pro' ); ?></label>
			<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'rss' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'rss' )); ?>" value="<?php echo esc_url( $instance['rss'] ); ?>" placeholder="<?php echo esc_attr( 'https://', 'vt-blogging-pro' ); ?>" />
		</p>

	<?php

	}

} // class vt_blogging_pro_social_widget
?>