<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.4.0
 */

defined( 'ABSPATH' ) || exit;

get_header( 'shop' ); ?>

<?php if (get_theme_mod('display-wc-sidebar', 0) == 1) : ?>
	<div id="primary" class="content-area content-product clear <?php vt_blogging_pro_container_class(); ?>">
<?php else : ?>
	<div id="primary" class="content-area content-product content-full clear <?php vt_blogging_pro_container_class(); ?>">
<?php endif; ?>

	<?php
		/**
		 * Hook: woocommerce_before_main_content.
		 *
		 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
		 * @hooked woocommerce_breadcrumb - 20
		 * @hooked WC_Structured_Data::generate_website_data() - 30
		 */
		do_action( 'woocommerce_before_main_content' );
	?>

	<?php if (get_theme_mod('display-wc-page-title', 1) == 1) { ?>
	  <header class="woocommerce-products-header">
		<h2 class="woocommerce-products-header__title page-title"><?php woocommerce_page_title(); ?></h2>
		<?php
			/**
			 * Hook: woocommerce_archive_description.
			 *
			 * @hooked woocommerce_taxonomy_archive_description - 10
			 * @hooked woocommerce_product_archive_description - 10
			 */
			do_action( 'woocommerce_archive_description' );
		?>
	  </header>
	<?php } ?>
	
	<?php if ( woocommerce_product_loop() ) {
	/**
	 * Hook: woocommerce_before_shop_loop.
	 *
	 * @hooked wc_print_notices - 10
	 * @hooked woocommerce_result_count - 20
	 * @hooked woocommerce_catalog_ordering - 30
	 */
		do_action( 'woocommerce_before_shop_loop' );

		woocommerce_product_loop_start(); 

		if ( wc_get_loop_prop( 'total' ) ) {
			while ( have_posts() ) {
				the_post();

				/**
				 * Hook: woocommerce_shop_loop.
				 *
				 * @hooked WC_Structured_Data::generate_product_data() - 10
				 */
				do_action( 'woocommerce_shop_loop' );

				wc_get_template_part( 'content', 'product' );
			}
		}

		woocommerce_product_loop_end();

		/**
		 * Hook: woocommerce_after_shop_loop.
		 *
		 * @hooked woocommerce_pagination - 10
		 */
		do_action( 'woocommerce_after_shop_loop' );
	} else {
		/**
		 * Hook: woocommerce_no_products_found.
		 *
		 * @hooked wc_no_products_found - 10
		 */
		do_action( 'woocommerce_no_products_found' );
	}

	/**
	 * Hook: woocommerce_after_main_content.
	 *
	 * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
	 */
	do_action( 'woocommerce_after_main_content' );
	?>
	
</div><!-- #end primary -->
  
<?php	
	if ( !get_theme_mod( 'display-wc-sidebar', 1) == 0) :
		// If enable Shop Sidebar, Let do this.
		get_template_part('woocommerce/sidebar', 'shop');
		
	endif;
	
	get_footer( 'shop' );
	
?>